====
Anti
====

Модуль для работы с браузерами, метрикой, вебмастером и пр.

 - Позволяет получать данные по позициям
 - Позволяет получать суп из поиска Яндекса и Гугла
 - Утилиты решают проблемы получения доноров, бэклинков, ТИЦ, PR и пр.

Импорт модулей:

from anti import openYandex, openGoogle, SeoParser, Metrika, Webmaster

0.7.1 Изменения

 - Добавлен балансировщик между серверами
 - Уменьшено количество sql запросов к базе

0.7.2
 - Балансировщик на redis

0.7.3
 - Fix: пустая выдача

0.7.4
 - Fix SeoParser: поправлена выдача страниц в индексе

1.0.1
 - Доделаны необходимые ф-ции для манипуляции с данными

1.0.2
 - Добавлена региональность

1.0.3
 - Добавлена ф-ция pages_of_site_in_index_google

1.0.4
 - Добавлены ф-ции получения возраста домена и посещений по liveinternet

1.0.5
 - Поправлена фитча с блоками. Добавлен 1ый пункт в whitelist. Добавлена ф-ция очищения текущего кэша.

1.1.0
 - Исправлена логика работы по сохранению и получению данных(Теперь все сохраняется в redis, а потом в postgres)

1.1.1
 - Добавлено получение позиций из кэша редиса

1.2.0
 - Удалены ф-ции multy. get_yandex_cache_pos получает позиции из redis. В базу данных теперь сохраняем отдельно.

1.2.1
 - Добавлена очистка кэша

1.2.2
 - Изменена работа с Webmaster и Metrika

1.2.3
 - Поправлены ошибки в seoparser

1.2.4
 - urllib и urllib2 заменены на requests

1.2.5
 - поправлена ф-ция получения PR

1.2.6
 - изменено получение данных из вебмастера + поправлена ф-ция get_normal_url_decode

1.2.7
 - Исправлена ошибка в SeoUtils

1.2.8
 - Добавлен параметр self.quote в SeoUtils

1.2.9
 - Порты вынесены в конфиг

1.3.0
 - Зависимости приведены в порядок

1.3.1
 - Исправлен фикс в выдаче normalize=True(get_yandex_cache_pos)

1.3.2
 - Добавили отдельный сервер под балансер

1.3.3
 - Поисковик поменял верстку

1.3.4
 - Изменена верстка при получении выдачи по сайту

1.3.5
 - Получение адреса страниц вместо относительного url

1.3.6
 - Исправлена ошибка: передача пустого списка как значения по умолчанию

1.3.7
 - Поправлено получение страниц в индексе

1.3.8
 - Добавлен timeout к запросам requests

1.4.0
 - Переделан функционал работы с redis. Теперь проверка идет по json.

1.4.1
 - Поправлен апдейт redis_key

1.4.2
 - Еще один hotfix для redis_key

1.4.3
 - Поменяли на контекстный менеджер

1.4.3.3
 - Обновил метод GetYaca в seoutils

1.4.4
 - Добавлен storage аргумент в функцию get_yandex_cache_pos

1.5.0
 - Добавлен декоратор на исключения

1.5.3
 - Поисковик ввел странное решение в верстку
